@@ -587,6 +587,8 @@ class FabioImage(_FabioArray):
     def previous(self):
         """ returns the previous file in the series as a fabioimage """
         from .openimage import openimage
+        if self.filename is None:
+            raise IOError()
         return openimage(fabioutils.previous_filename(self.filename))
 
     def next(self):
@@ -595,6 +597,8 @@ class FabioImage(_FabioArray):
         :raise IOError: When there is no next file in the series.
         """
         from .openimage import openimage
+        if self.filename is None:
+            raise IOError()
         return openimage(
             fabioutils.next_filename(self.filename))
 
@@ -853,7 +857,9 @@ class FabioImage(_FabioArray):
             try:
                 current_image = current_image.next()
             except IOError:
-                raise StopIteration
+                break
+        if sys.version_info[0:2] < (3, 5):
+            raise StopIteration()
 
 
 fabioimage = FabioImage
