@@ -73,7 +73,8 @@ class Mar345Image(FabioImage):
 
     DESCRIPTION = "File format from Mar345 imaging plate and Mar555 flat panel"
 
-    DEFAULT_EXTENSIONS = ["mar2300"]
+    DEFAULT_EXTENSIONS = ["mar2300", "mar1200", "mar1600", "mar2000",  # 150µm pixel size
+                          "mar3450", "mar3000", "mar2400", "mar1800"]  # 100µm pixel size
 
     def __init__(self, *args, **kwargs):
         FabioImage.__init__(self, *args, **kwargs)
@@ -244,7 +245,7 @@ class Mar345Image(FabioImage):
         self.header["HIGH"] = str(binheader[2])
         if self.swap_needed:
             binheader.byteswap(True)
-        return binheader.tostring()
+        return binheader.tobytes()
 
     def ascii_header(self, linesep="\n", size=4096):
         """
@@ -375,7 +376,7 @@ class Mar345Image(FabioImage):
         tmp[:nb_pix, 1] = flt_data[pix_location]
         if self.swap_needed:
             tmp.byteswap(True)
-        return tmp.tostring()
+        return tmp.tobytes()
 
     def nb_overflow_pixels(self):
         return (self.data > 65535).sum()
